tag_list: Create a tag list (sibling container)

View source: R/tags.R

tag_listR Documentation

Create a tag list (sibling container)

Description

Useful when you want to collect sibling nodes into a single object without wrapping them in a parent element.

Usage

tag_list(...)

Arguments

...

Tags, text, or other renderable objects /// Optional.

Value

A list of class "hypertext.tag.list".

Examples

tl <- tag_list(tags$p("one"), tags$p("two"))
render(tl)

hypertext documentation built on April 18, 2026, 1:06 a.m.