| tag_list | R Documentation |
Useful when you want to collect sibling nodes into a single object without wrapping them in a parent element.
tag_list(...)
... |
Tags, text, or other renderable objects /// Optional. |
A list of class "hypertext.tag.list".
tl <- tag_list(tags$p("one"), tags$p("two"))
render(tl)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.