Useful when you want to collect sibling nodes into a single object without wrapping them in a parent element.
Examples
tl <- tag_list(tags$p("one"), tags$p("two"))
render(tl)
#> [1] "<p>one</p><p>two</p>"
Useful when you want to collect sibling nodes into a single object without wrapping them in a parent element.
tl <- tag_list(tags$p("one"), tags$p("two"))
render(tl)
#> [1] "<p>one</p><p>two</p>"